==> claromentis-framework-8.13.65-b8aa1bfb.zip: web/intranet/core/classes/ORM/Analogue/DalDbAdapter.php <==
<?php
namespace Claromentis\Core\ORM\Analogue;

$GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"] ?: array()) + array();
use Analogue\ORM\Drivers\DBAdapter;
use Illuminate\Database\Query\Builder;
use Analogue\ORM\Drivers\IlluminateQueryBuilder;




class DalDbAdapter implements DBAdapter
{
    
    
    
    
    protected $connection;
    
    
    
    
    
    
    public function __construct(DalConnection $_360c647d4c765175a91a97e78e9f9558)
    {
        $this->connection = $_360c647d4c765175a91a97e78e9f9558;
    }
    
    
    
    
    
    
    public function getQuery()
    {
        $_360c647d4c765175a91a97e78e9f9558 = $this->connection;
        $_2a3ade488fb28d70d0abcd6a20c1ecb0 = $_360c647d4c765175a91a97e78e9f9558->getQueryGrammar();
        $_5efd9761a41b4a8c1005ab703727e1ab = $_360c647d4c765175a91a97e78e9f9558->getPostProcessor();
        return new IlluminateQueryBuilder($_360c647d4c765175a91a97e78e9f9558, $_2a3ade488fb28d70d0abcd6a20c1ecb0, $_5efd9761a41b4a8c1005ab703727e1ab);
    }
    
    
    
    
    
    
    public function getDateFormat() : string
    {
        return $this->connection->getQueryGrammar()->getDateFormat();
    }
    
    
    
    
    
    
    public function beginTransaction()
    {
        $this->connection->beginTransaction();
    }
    
    
    
    
    
    
    public function commit()
    {
        $this->connection->commit();
    }
    
    
    
    
    
    
    public function rollback()
    {
        $this->connection->rollBack();
    }
    
    
    
    
    
    
    
    
    
    public function fromDatabase(array $_a0006f2e6058ce959e86bebdcded2da8) : array
    {
        return $_a0006f2e6058ce959e86bebdcded2da8;
    }
}

==> claromentis-framework-9.6.5-177028fb.zip: web/intranet/core/classes/ORM/Analogue/DalDbAdapter.php <==
<?php
namespace Claromentis\Core\ORM\Analogue;

$GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"] = (@$GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"] ?: array()) + array();
use Analogue\ORM\Drivers\DBAdapter;
use Illuminate\Database\Query\Builder;
use Analogue\ORM\Drivers\IlluminateQueryBuilder;




class DalDbAdapter implements DBAdapter
{
    
    
    
    
    protected $connection;
    
    
    
    
    
    
    public function __construct(DalConnection $_360c647d4c765175a91a97e78e9f9558)
    {
        $this->connection = $_360c647d4c765175a91a97e78e9f9558;
    }
    
    
    
    
    
    
    public function getQuery()
    {
        $_360c647d4c765175a91a97e78e9f9558 = $this->connection;
        $_2a3ade488fb28d70d0abcd6a20c1ecb0 = $_360c647d4c765175a91a97e78e9f9558->getQueryGrammar();
        $_5efd9761a41b4a8c1005ab703727e1ab = $_360c647d4c765175a91a97e78e9f9558->getPostProcessor();
        return new IlluminateQueryBuilder($_360c647d4c765175a91a97e78e9f9558, $_2a3ade488fb28d70d0abcd6a20c1ecb0, $_5efd9761a41b4a8c1005ab703727e1ab);
    }
    
    
    
    
    
    
    public function getDateFormat() : string
    {
        return $this->connection->getQueryGrammar()->getDateFormat();
    }
    
    
    
    
    
    
    public function beginTransaction()
    {
        $this->connection->beginTransaction();
    }
    
    
    
    
    
    
    public function commit()
    {
        $this->connection->commit();
    }
    
    
    
    
    
    
    public function rollback()
    {
        $this->connection->rollBack();
    }
    
    
    
    
    
    
    
    
    
    public function fromDatabase(array $_a0006f2e6058ce959e86bebdcded2da8) : array
    {
        return $_a0006f2e6058ce959e86bebdcded2da8;
    }
}
